======
Groups
======

The ``lda-users`` group is for general discussion of lda, including modeling and
installation issues:

- `lda users group <https://groups.google.com/forum/#!forum/lda-users>`_

You can subscribe by sending an e-mail to ``lda-users+subscribe@googlegroups.com``.
